@@ -2,6 +2,7 @@
 
     Copyright (C) 2001 Stefan Westerfeld
                        stefan@space.twc.de
+                  2003 Arnold Krille <arnold@arnoldarts.de>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -56,13 +57,22 @@ public:
 	/**
 	 * creates a new KArtsWidget
 	 */
-	KArtsWidget(QWidget* parent = 0, const char* name = 0);
+	KArtsWidget( QWidget* parent, const char* name );
 
 	/**
 	 * creates a new KArtsWidget and sets the content to an Arts::Widget
 	 */
-	KArtsWidget(Arts::Widget content, QWidget* parent = 0, const char* name = 0);
+	KArtsWidget( Arts::Widget content, QWidget* parent, const char* name );
 	
+	/**
+	 * creates a new KArtsWidget with WidgetFlags and content
+	 *
+	 * BCI: should replace the above in the next major release. ( akrille )
+	 */
+	KArtsWidget( Arts::Widget, QWidget* =0, const char* =0, WFlags =0 );
+	// same without the content
+	KArtsWidget( QWidget* =0, const char* =0, WFlags =0 );
+
 	/**
 	 * destructor
 	 */
