@@ -1,7 +1,9 @@
-    /*
+/*
 
     Copyright (C) 2001 Stefan Westerfeld
-	                   <stefan@space.twc.de>
+                       <stefan@space.twc.de>
+                  2003 Matthias Kretz <kretz@kde.org>
+                  2003 Arnold Krille <arnold@arnoldarts.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,21 +17,24 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     */
 
 #include "environmentview.h"
-#include "qdir.h"
-#include "qfile.h"
-#include "qlistbox.h"
-#include "qpushbutton.h"
-#include "kartswidget.h"
-#include "klocale.h"
-#include "main.h"
+#include <qdir.h>
+#include <qfile.h>
+#include <qpushbutton.h>
+
+#include <klistbox.h>
+#include <kartswidget.h>
+#include <klocale.h>
+#include <kiconloader.h>
 #include <stdio.h>
 #include <fstream>
-#include <vector.h>
+#include <vector>
+
+#include <qlayout.h>
 
 #define DEFAULT_ENV_FILENAME "~/default.arts-env"
 
@@ -56,18 +61,25 @@ public:
 	}
 };
 
-EnvironmentView::EnvironmentView(Container container) : container(container)
+EnvironmentView::EnvironmentView( Container container, QWidget* parent, const char* name ) : Template_ArtsView( parent,name ), container(container)
 {
+	this->setCaption( i18n( "Environment" ) );
+	this->setIcon( MainBarIcon( "artsenvironment", 32 ) );
+	QVBoxLayout* _layout = new QVBoxLayout( this );
+	_layout->setAutoAdd( true );
         defaultEnvFileName = DEFAULT_ENV_FILENAME;
         defaultEnvFileName.replace('~', QDir::homeDirPath());
-        listBox = new QListBox(this);
+        listBox = new KListBox(this);
 	update();
-	connect(listBox,SIGNAL(doubleClicked(QListBoxItem*)),
+	connect(listBox,SIGNAL(executed(QListBoxItem*)),
 			this,SLOT(view(QListBoxItem*)));
 	
 	QPushButton *mixerButton = new QPushButton(i18n("Add Mixer"), this);
 	connect(mixerButton, SIGNAL(clicked()), this, SLOT(addMixer()));
 
+	QPushButton *effectRackButton = new QPushButton(i18n("Add Effect Rack"), this);
+	connect(effectRackButton, SIGNAL(clicked()), this, SLOT(addEffectRack()));
+
 	QPushButton *delButton = new QPushButton(i18n("Delete Item"), this);
 	connect(delButton, SIGNAL(clicked()), this, SLOT(delItem()));
 
@@ -81,12 +93,6 @@ EnvironmentView::EnvironmentView(Container container) : container(container)
 	show();
 }
 
-void EnvironmentView::closeEvent(QCloseEvent *e)
-{
-	e->accept();
-	emit closed();
-}
-
 void EnvironmentView::view(QListBoxItem *i)
 {
 	ItemView *iv = static_cast<ItemView*>(i);
@@ -114,6 +120,12 @@ void EnvironmentView::addMixer()
 	update();
 }
 
+void EnvironmentView::addEffectRack()
+{
+	container.createItem("Arts::Environment::EffectRackItem");
+	update();
+}
+
 void EnvironmentView::delItem()
 {
 	int i = listBox->currentItem();
@@ -128,8 +140,8 @@ void EnvironmentView::update()
 {
 	listBox->clear();
 
-	vector<Item> *items = container.items();
-	for(vector<Item>::iterator i = items->begin(); i != items->end(); i++)
+	std::vector<Item> *items = container.items();
+	for(std::vector<Item>::iterator i = items->begin(); i != items->end(); i++)
 		(void)new ItemView(listBox, *i);
 	delete items;
 }
@@ -138,7 +150,7 @@ void EnvironmentView::load()
 {
 	std::ifstream infile(QFile::encodeName(defaultEnvFileName).data());
 	std::string line;
-	vector<std::string> strseq;
+	std::vector<std::string> strseq;
 
 	while(getline(infile,line))
 		strseq.push_back(line);
@@ -148,12 +160,12 @@ void EnvironmentView::load()
 
 void EnvironmentView::save()
 {
-	vector<std::string> *strseq;
+	std::vector<std::string> *strseq;
 	strseq = defaultEnvironment().saveToList();
 
 	std::ofstream outfile(QFile::encodeName(defaultEnvFileName).data());
-	for(vector<std::string>::iterator i = strseq->begin(); i != strseq->end(); i++)
-		outfile << *i << endl;
+	for(std::vector<std::string>::iterator i = strseq->begin(); i != strseq->end(); i++)
+		outfile << ( *i ) << std::endl;
 	delete strseq;
 }
 #include "environmentview.moc"
