@@ -15,7 +15,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- *  $Id: kfile_ogg.cpp,v 1.22.2.4 2003/09/08 22:57:23 mueller Exp $
+ *  $Id: kfile_ogg.cpp,v 1.30 2004/06/26 10:12:15 binner Exp $
  */
 
 #include "kfile_ogg.h"
@@ -67,7 +67,7 @@ KOggPlugin::KOggPlugin( QObject *parent, const char *name,
 {
     kdDebug(7034) << "ogg plugin\n";
     
-    KFileMimeTypeInfo* info = addMimeTypeInfo( "application/x-ogg" );
+    KFileMimeTypeInfo* info = addMimeTypeInfo( "audio/vorbis" );
 
     KFileMimeTypeInfo::GroupInfo* group = 0;
 
@@ -75,7 +75,7 @@ KOggPlugin::KOggPlugin( QObject *parent, const char *name,
     group = addGroupInfo(info, "Comment", i18n("Comment"));
     setAttributes(group, KFileMimeTypeInfo::Addable |
                          KFileMimeTypeInfo::Removable);
-    
+
     KFileMimeTypeInfo::ItemInfo* item = 0;
 
     item = addItemInfo(group, "Artist", i18n("Artist"), QVariant::String);
@@ -123,22 +123,22 @@ KOggPlugin::KOggPlugin( QObject *parent, const char *name,
     addItemInfo(group, "Version", i18n("Version"), QVariant::Int);
     addItemInfo(group, "Channels", i18n("Channels"), QVariant::Int);
 
-    item = addItemInfo(group, "Sample Rate", i18n("Sample rate"), QVariant::Int);
+    item = addItemInfo(group, "Sample Rate", i18n("Sample Rate"), QVariant::Int);
     setSuffix(item, i18n(" Hz"));
 
-    item = addItemInfo(group, "UpperBitrate", i18n("Upper bitrate"),
+    item = addItemInfo(group, "UpperBitrate", i18n("Upper Bitrate"),
                        QVariant::Int);
     setSuffix(item, i18n(" kbps"));
     
-    item = addItemInfo(group, "LowerBitrate", i18n("Lower bitrate"),
+    item = addItemInfo(group, "LowerBitrate", i18n("Lower Bitrate"),
                        QVariant::Int);
     setSuffix(item, i18n(" kbps"));
 
-    item = addItemInfo(group, "NominalBitrate", i18n("Nominal bitrate"),
+    item = addItemInfo(group, "NominalBitrate", i18n("Nominal Bitrate"),
                        QVariant::Int);
     setSuffix(item, i18n(" kbps"));
     
-    item = addItemInfo(group, "Bitrate", i18n("Average bitrate"), 
+    item = addItemInfo(group, "Bitrate", i18n("Average Bitrate"), 
                        QVariant::Int);
     setAttributes(item, KFileMimeTypeInfo::Averaged);
     setHint(item, KFileMimeTypeInfo::Bitrate);
@@ -171,7 +171,11 @@ bool KOggPlugin::readInfo( KFileMetaInfo& info, uint what )
     memset(&vf, 0, sizeof(OggVorbis_File));
   
     fp = fopen(QFile::encodeName(info.path()),"rb");
-    if (!fp) return false;
+    if (!fp)
+    {
+        kdDebug(7034) << "Unable to open " << QFile::encodeName(info.path()) << endl;
+        return false;
+    }
 
     rc = ov_open(fp,&vf,NULL,0);
 
