@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 59 Temple
 
     Send comments and bug fixes to larrosa@kde.org
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
@@ -39,7 +39,6 @@
 #include <kfontdialog.h>
 #include <kglobal.h>
 #include <kiconloader.h>
-#include <kkeydialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <ktoolbar.h>
@@ -48,7 +47,7 @@
 #include <kaction.h>
 #include <kstdaction.h>
 #include <kurldrag.h>
-
+#include <kedittoolbar.h>
 #include <dcopclient.h>
 
 #include "kmidframe.h"
@@ -152,13 +151,15 @@ kmidFrame::kmidFrame(const char *name)
 		SLOT(options_AutomaticText()), actionCollection(),
 		"option_automatictext");
 
-    (void)new KToggleAction(i18n("Show &Volume Bar"), "volume",
+    KToggleAction* togact = new KToggleAction(i18n("Show &Volume Bar"), "volume",
 		0, this, SLOT(options_ShowVolumeBar()), actionCollection(),
 		"toggle_volumebar");
+    togact->setCheckedState(i18n("Hide &Volume Bar"));
 
-    (void)new KToggleAction(i18n("Show &Channel View"), "piano",
+    togact = new KToggleAction(i18n("Show &Channel View"), "piano",
 		0, this, SLOT(options_ShowChannelView()), actionCollection(),
 		"toggle_channelview");
+    togact->setCheckedState(i18n("Hide &Channel View"));
 
     (void)new KAction(i18n("Channel View &Options..."), 0, this,
 		SLOT(options_ChannelViewOptions()), actionCollection(),
@@ -168,13 +169,11 @@ kmidFrame::kmidFrame(const char *name)
 		SLOT(options_FontChange()), actionCollection(),
 		"change_font");
 
-    KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
-
     (void)new KAction(i18n("MIDI &Setup..."), 0, this,
 		SLOT(options_MidiSetup()), actionCollection(), "midi_setup");
 
 
-    createGUI( "kmidui.rc" );
+    setupGUI((ToolBar | Keys | StatusBar | Save | Create ), "kmidui.rc" );
 
     KConfig *cfg=kapp->config();
     cfg->setGroup("KMid");
@@ -467,7 +466,7 @@ void kmidFrame::options_MidiSetup()
   if (kmidclient->devman()->checkInit()<0)
   {
     KMessageBox::error(this,
-	i18n("Couldn't open /dev/sequencer to get some info.\nProbably there is another program using it."));
+	i18n("Could not open /dev/sequencer to get some info.\nProbably there is another program using it."));
     return;
   }
   MidiConfigDialog *dlg;
@@ -625,12 +624,6 @@ void kmidFrame::options_ChannelViewOptions()
   delete dlg;
 }
 
-void kmidFrame::slotConfigureKeys()
-{
-    KKeyDialog::configure( actionCollection(), this );
-}
-
-
 void kmidFrame::openURL( const QString url )
 {
   int c=autoAddSongToCollection(url,1);
