@@ -42,7 +42,7 @@
 #define OSS_MIXER
 #endif
 
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__bsdi__) || defined(_UNIXWARE)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__bsdi__) || defined(_UNIXWARE)
 #define OSS_MIXER
 #endif
 
@@ -105,7 +105,7 @@ MixerFactory g_mixerFactories[] = {
 #endif
 
 #if defined(SUN_MIXER)
-    { SUN_getMixer, SUN_getMixerSet , SUN_getDriverName },
+    { SUN_getMixer, 0 , SUN_getDriverName },
 #endif
 
 #if defined(IRIX_MIXER)
@@ -113,11 +113,11 @@ MixerFactory g_mixerFactories[] = {
 #endif
 
 #if defined(ALSA_MIXER)
-    { ALSA_getMixer, ALSA_getMixerSet, ALSA_getDriverName },
+    { ALSA_getMixer, 0, ALSA_getDriverName },
 #endif
 
 #if defined(OSS_MIXER)
-    { OSS_getMixer, OSS_getMixerSet , OSS_getDriverName },
+    { OSS_getMixer, 0 , OSS_getDriverName },
 #endif
 
 #if defined(HPUX_MIXER)
