@@ -18,6 +18,7 @@
  * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
+#include "mixertoolbox.h"
 #include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
@@ -28,10 +29,11 @@
 #include <kdebug.h>
 #include <qptrlist.h>
 
+#include "kmixtoolbox.h"
 #include "mixer.h"
 #include "version.h"
 
-static const char *description =
+static const char description[] =
 I18N_NOOP("kmixctrl - kmix volume save/restore utility");
 
 static KCmdLineOptions options[] =
@@ -40,11 +42,11 @@ static KCmdLineOptions options[] =
    { "save", I18N_NOOP("Save current volumes as default"), 0 },
    { "r", 0, 0 },
    { "restore", I18N_NOOP("Restore default volumes"), 0 },
-   { 0, 0, 0 }
+   KCmdLineLastOption
    // INSERT YOUR COMMANDLINE OPTIONS HERE
 };
 
-int main(int argc, char *argv[])
+extern "C" int kdemain(int argc, char *argv[])
 {
    KLocale::setMainCatalogue("kmix");
    KAboutData aboutData( "kmixctrl", I18N_NOOP("KMixCtrl"),
@@ -56,35 +58,23 @@ int main(int argc, char *argv[])
    KCmdLineArgs::init( argc, argv, &aboutData );
    KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
-   KApplication app;
+   KApplication app( false, false );
 
    // get maximum values
-   KConfig *config= new KConfig("kcmkmixrc", false);
+   KConfig *config= new KConfig("kmixrc", true, false);
    config->setGroup("Misc");
-   int maxCards = config->readNumEntry( "maxCards", 2 );
-   int maxDevices = config->readNumEntry( "maxDevices", 2 );
    delete config;
 
    // create mixers
    QPtrList<Mixer> mixers;
-   int drvNum = Mixer::getDriverNum();
-   for( int drv=0; drv<drvNum && mixers.count()==0; drv++ )
-       for ( int dev=0; dev<maxDevices; dev++ )
-           for ( int card=0; card<maxCards; card++ ) {
-
-               Mixer *mixer = Mixer::getMixer( drv, dev, card );
-               int mixerError = mixer->grab();
-               if ( mixerError!=0 )
-                   delete mixer;
-               else
-                   mixers.append( mixer );
-           }
+   MixerToolBox::initMixer(mixers, false);
 
    // load volumes
    if ( args->isSet("restore") )
    {
-      for (Mixer *mixer=mixers.first(); mixer!=0; mixer=mixers.next())
-	 mixer->volumeLoad( KGlobal::config() );
+       for (Mixer *mixer=mixers.first(); mixer!=0; mixer=mixers.next()) {
+	   mixer->volumeLoad( KGlobal::config() );
+       }
    }
 
    // save volumes
@@ -93,4 +83,6 @@ int main(int argc, char *argv[])
       for (Mixer *mixer=mixers.first(); mixer!=0; mixer=mixers.next())
 	 mixer->volumeSave( KGlobal::config() );
    }
+
+   return 0;
 }
