@@ -30,8 +30,9 @@
 class Mixer;
 class QFrame;
 class KAudioPlayer;
-class KMixMasterVolume;
+class ViewDockAreaPopup;
 class MixDeviceWidget;
+class Volume;
 
 class KMixDockWidget : public KSystemTray  {
    Q_OBJECT
@@ -39,15 +40,20 @@ class KMixDockWidget : public KSystemTray  {
    friend class KMixWindow;
 
  public:
-   KMixDockWidget(Mixer *, QWidget *parent=0, const char *name=0);
+   KMixDockWidget(Mixer *, QWidget *parent=0, const char *name=0, bool volumePopup=true);
    ~KMixDockWidget();
 
-   void updatePixmap();
    void setErrorPixmap();
    void ignoreNextEvent();
+   ViewDockAreaPopup* getDockAreaPopup();
+
+	Mixer *m_mixer;
+   ViewDockAreaPopup *_dockAreaPopup;
+   KAudioPlayer *_audioPlayer;
 
  public slots:
-   void setVolumeTip(int, Volume );
+   void setVolumeTip();
+   void updatePixmap();
 
  protected:
    void createMasterVolWidget();
@@ -58,25 +64,11 @@ class KMixDockWidget : public KSystemTray  {
    void toggleMinimizeRestore();
 
  private:
-   Mixer *m_mixer;
-   KMixMasterVolume *masterVol;
-   KAudioPlayer *audioPlayer;
-   bool m_playBeepOnVolumeChange;
-   bool m_ignoreNextEvent;
-};
-
-class KMixMasterVolume : public QVBox
-{
-    public:
-        KMixMasterVolume(QWidget* parent, const char* name, Mixer* mixer, KMixDockWidget *dockW);
-        ~KMixMasterVolume() {}
-        MixDeviceWidget* mixerWidget() { return mdw; }
-
-    protected:
-        MixDeviceWidget *mdw;
-        KMixDockWidget *dock;
-
-        void mousePressEvent(QMouseEvent *e);
+   bool _playBeepOnVolumeChange;
+   bool _ignoreNextEvent;
+   int  _oldToolTipValue;
+   char _oldPixmapType;
+   bool _volumePopup;
 };
 
 #endif
