@@ -27,6 +27,7 @@
 class KMixPrefWidget;
 class KMixApp;
 class QCheckBox;
+class QRadioButton;
 
 class 
 KMixPrefDlg : public KDialogBase  
@@ -55,6 +56,9 @@ KMixPrefDlg : public KDialogBase
    QCheckBox *m_hideOnCloseChk;
    QCheckBox *m_showTicks;
    QCheckBox *m_showLabels;
+   QCheckBox *m_onLogin;
+   QRadioButton *_rbVertical;
+   QRadioButton *_rbHorizontal;
 };
 
 #endif
