@@ -32,7 +32,6 @@
 #include <klocale.h>
 #include <kdebug.h>
 #include <kapplication.h>
-#include <kkeydialog.h>
 #include <kaction.h>
 #include <kconfig.h>
 #include <qlayout.h>
@@ -81,7 +80,7 @@ KRecPrivate::~KRecPrivate() {
 	//kdDebug( 60005 ) << k_funcinfo << endl;
 	mainwidget->_artswidget = Arts::StereoVolumeControlGui::null();
 	delete _currentFile;
-        _currentFile = 0;
+	_currentFile = 0;
 	//kdDebug( 60005 ) << k_funcinfo << "done." << endl;
 }
 
@@ -153,7 +152,7 @@ bool KRecPrivate::closeFile() {
 void KRecPrivate::exportFile() {
 kdDebug( 60005 ) << k_funcinfo << endl;
 	if ( _currentFile ) {
-		QString filename = KFileDialog::getSaveFileName( "", KRecGlobal::the()->exportFormatEndings(), _impl, "Export File as" );
+		QString filename = KFileDialog::getSaveFileName( "", KRecGlobal::the()->exportFormatEndings(), _impl, "Export File As" );
 		if ( !filename.isNull() ) {
 			int lastdot = filename.find( '.', -5 );
 			QString ending = filename.right( filename.length()-lastdot-1 );
@@ -282,7 +281,7 @@ kdDebug( 60005 ) << k_funcinfo << endl;
 	// * * * Actions * * *
 	d->artsactions = new ArtsActions( d->server, actionCollection(), this );
 
-	KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
+	KStdAction::keyBindings( guiFactory(), SLOT( configureShortcuts() ), actionCollection() );
 	KStdAction::preferences( d, SLOT( showConfDialog() ), actionCollection() );
 
 	KStdAction::openNew( d, SLOT( newFile() ), actionCollection() );
@@ -345,12 +344,6 @@ kdDebug( 60005 ) << k_funcinfo << endl;
 	d->checkActions();
 }
 
-void KRecord::slotConfigureKeys()
-{
-	KKeyDialog::configure( actionCollection(), this );
-}
-
-
 KRecord::~KRecord(){
 kdDebug( 60005 ) << k_funcinfo << endl; // (DEBUG)
 	stopRec();
