@@ -1,7 +1,7 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: docking.h,v 1.9 2001/03/25 04:13:24 tibirna Exp $
+ * $Id: docking.h,v 1.12 2004/03/10 19:24:29 aseigo Exp $
  *
  *              Copyright (C) 1997 Bernd Johannes Wuebben
  *                      wuebben@math.cornell.edu
@@ -22,7 +22,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 
@@ -37,25 +37,36 @@
 #include <qpoint.h>
 #include <kdockwindow.h>
 
-extern int      ibytes;
-extern int      obytes;
-
 class KSCD;
 
-class DockWidget : public KSystemTray {
+class KAction;
+class KToggleAction;
+class KPassivePopup;
 
-  Q_OBJECT
+class DockWidget : public KSystemTray
+{
+    Q_OBJECT
 
 public:
-  DockWidget( KSCD* parent, const char *name=0);
-  ~DockWidget();
+    DockWidget( KSCD* parent, const char *name=0);
+    ~DockWidget();
 
 public slots:
-  void setToolTip(const QString& text);
+    void setToolTip(const QString& text);
+    void createPopup(const QString& songName, bool addButtons = true);
 
 private:
-  QString tip;
+    virtual void wheelEvent( QWheelEvent *e);
 
+    KPassivePopup* m_popup;
+
+    KAction* m_forwardAction;
+    KAction* m_backAction;
+
+    QPixmap m_backPix;
+    QPixmap m_forwardPix;
+
+    QString tip;
 };
 
 #endif
