@@ -1,7 +1,7 @@
 /*
    Kscd - A simple cd player for the KDE Project
 
-   $Id: kscd.h,v 1.86.2.2 2004/03/12 14:38:40 waba Exp $
+   $Id: kscd.h,v 1.103 2004/08/03 22:53:39 kernalex Exp $
 
    Copyright (c) 1997 Bernd Johannes Wuebben math.cornell.edu
 
@@ -77,22 +77,23 @@
 #define KSCDMAGIC 0
 #endif
 
-
 #include "ledlamp.h"
 #include "panel.h"
+#include "prefs.h"
+#include "configWidget.h"
 #include <kapplication.h>
+#include <kconfigdialog.h>
 #include <kprocess.h>
 #include <krandomsequence.h>
 #include <dcopobject.h>
 
-class CDDBSetup;
-class ConfigDlg;
-class CDDialog;
+class CDDBDlg;
+class DockWidget;
 class QGridLayout;
 class KActionCollection;
+class KToggleAction;
 class KVolumeControl;
 
-
 using namespace KCDDB;
 
 struct mgconfigstruct
@@ -117,6 +118,7 @@ class KSCD : public kscdPanelDlg, public KSessionManaged, virtual public DCOPObj
 
 
 k_dcop:
+    bool playing();
     void play() { playClicked(); }
     void stop() { stopClicked(); }
     void previous() { prevClicked(); }
@@ -129,9 +131,11 @@ k_dcop:
     void toggleTimeDisplay() { cycleplaytimemode(); }
     void cddbDialog() { CDDialogSelected(); }
     void optionDialog() { showConfig(); }
-    void setTrack(int t) { trackSelected(t >= 1 ? t - 1 : 0); }
+    void setTrack(int t) { trackSelected(t > 0 ? t - 1 : 0); }
+    void volumeDown() { decVolume(); }
+    void volumeUp() { incVolume(); }
     void setVolume(int v);
-    int  getVolume() { return volume; }
+    int  getVolume() { return Prefs::volume(); }
     int currentTrack();
     QString currentTrackTitle();
     QString currentAlbum();
@@ -143,26 +147,13 @@ public:
     ~KSCD();
     virtual bool saveState(QSessionManager& sm);
 
-    bool dock() { return docking; }
     void setDocking(bool dock);
-    bool stopOnExit() { return stopexit; }
-    void setStopOnExit(bool stop) { stopexit = stop; }
-    bool autoPlay() { return autoplay; }
-    void setAutoplay(bool play) { autoplay = play; }
-    bool ejectOnFinish() { return ejectonfinish; }
-    void setEjectOnFinish(bool eject) { ejectonfinish = eject; }
     bool digitalPlayback();
-    unsigned int skipInterval() { return skipDelta; }
-    void setSkipInterval(unsigned int skip) { skipDelta = skip; }
-    QColor ledColor() { return led_color; }
-    QColor bgColor() { return background_color; }
-    void setColors(const QColor& LEDs, const QColor& bground);
-    void setDevicePaths(QString cd_device, QString audio_system, QString audio_device);
-    QString devicePath() { return cd_device_str; }
-    QString audioSystem() { return audio_system_str; }
-    QString audioDevice() { return audio_device_str; }
+    void setDevicePaths();
     QStringList audioSystems() { return audio_systems_list; }
 
+    KActionCollection* actionCollection() { return m_actions; }
+
 signals:
     void trackChanged(const QString&);
     void newServerList(const QStringList&);
@@ -171,33 +162,33 @@ public slots:
     void setColors();
     void togglequeryled();
     void randomSelected();
-    void setShuffle(bool shuffle);
+    void setShuffle(int shuffle); /* 0 -off, 1 - on, 2 - remake random list */
     void writeSettings();
     void initCDROM();
     void playClicked();
-    void nextClicked();
+    bool nextClicked();
     void prevClicked();
     void stopClicked();
     void ejectClicked();
-    void jumpToTime(int seconds);
+    void jumpToTime(int seconds, bool forcePlay = false);
     void quitClicked();
     void loopOn();
     void loopOff();
     void loopClicked();
+    void setRandomLabel(int mode);
     void cdMode();
-    void trackSelected( int );
+    void cdModeChanged(int previous, int current);
+    void trackSelected(int);
     void showConfig();
     void incVolume();
     void decVolume();
-    void volChanged( int );
+    void volChanged(int);
     void led_on();
     void led_off();
     void titlelabeltimeout();
     void cycleplaytimemode();
     void cycletimeout();
 
-    void performances(int);
-    void purchases(int);
     void information(int);
     void jumpTracks();
 
@@ -208,20 +199,33 @@ protected slots:
     void configureKeys();
     void setIcons();
 
+    void timeSliderPressed();
+    void timeSliderReleased();
+    void timeSliderMoved(int seconds);
+
 protected:
     // mostly start up stuff
     void readSettings();
     void initFont();
-    void initWorkMan();
     void drawPanel();
     void setupPopups();
     void setLEDs(const QString& symbols);
+    void resetTimeSlider(bool enabled);
+
+    void dragTime(int sec);
 
     void closeEvent( QCloseEvent *e );
     void keyPressEvent( QKeyEvent* e );
     bool event( QEvent *e );
     //    void focusOutEvent(QFocusEvent *e);
     void playtime();
+    void playtime(int seconds);
+    QString calculateDisplayedTime();
+    QString calculateDisplayedTime(int sec);
+    QString calculateDisplayedTime(int sec, int track);
+
+    void updateDisplayedTrack(int track);
+
     bool getArtist(QString& artist);
 
     void clearSongList();
@@ -229,26 +233,16 @@ protected:
     void populateSongList();
     void updatePlayPB(bool playing);
 
+    void updateConfigDialog(configWidget* widget);
+
 private:
-    ConfigDlg       *configDialog;
-    CDDialog        *cddialog;
+    KConfigDialog   *configDialog;
+    CDDBDlg         *cddialog;
     QPopupMenu      *mainPopup;
-    QPopupMenu      *purchPopup;
     QPopupMenu      *infoPopup;
 
-    // ML XXX
-    QGridLayout		*outerLO;
-
-    QColor              background_color;
-    QColor              led_color;
     BW_LED_Number       *trackTimeLED[6];
-    QLabel              *statuslabel;
-    QLabel              *titlelabel;
-    QLabel              *artistlabel;
-    QLabel              *volumelabel;
-    QLabel              *tracklabel;
-    QLabel              *totaltimelabel;
-    QLabel              *nLEDs;
+    
     QTimer              timer;
     QTimer              titlelabeltimer;
     QTimer              queryledtimer;
@@ -262,28 +256,14 @@ private:
 
 
     int                 jumpToTrack;
-    unsigned int        skipDelta;
-    int                 volume;
     LedLamp             *queryled;
     LedLamp             *loopled;
-    bool                randomplay;
     bool                randomplay_pending;
-    void song_list_complete(void);
-    bool                looping;
     bool                cddrive_is_ok;
     bool                have_new_cd;
-    int                 time_display_mode;
-    QString             cd_device_str;
-    QString             audio_system_str; /* arts, alsa or sun. empty means no cdda */
-    QString             audio_device_str; /* for alsa hw:0,0, for sun /dev/audio */
+    bool                updateTime;
     QStringList         audio_systems_list;
 
-    QPushButton         *makeButton( int, int, int, int, const QString& );
-
-
-
-    void cdtext(struct cdtext_info* p_cdtext);
-
   /**
    * select a random track from the current disc.
    *
@@ -294,27 +274,18 @@ private:
 
   /**
    * set the artist and title labels as well as the dock tooltip.
-   *
    */
-    void setArtistAndTitle(const QString& artist, const QString& title);
-
-    int             tmppos;
-    int             save_track;
+    void setArtist(const QString& artist);
+    void setTitle(int track);
 
     QStringList     pathlist;
     QStringList     tracktitlelist;
     QStringList     playlist;
-    int             playlistpointer;
     QStringList     extlist;
     QString         category;
     QString         genre;
     QFont           smallfont;
     QFont           verysmallfont;
-    bool            docking;
-    bool            autoplay;
-    bool            stopexit;
-    bool            ejectonfinish;
-    bool            digitalplayback;
 
 // cddb support
 public slots:
@@ -326,17 +297,22 @@ public slots:
     void CDDialogDone();
     void get_cddb_info(bool);
 
+private:
+    void get_cdtext_info();
+
 private:
     KCDDB::Client*  cddb;
     QString         xmcd_data;
     QStringList     cddbserverlist;
     QString         current_server;
     QStringList     cddbsubmitlist;
-    bool            updateDialog;
+    //bool            updateDialog;
     int             revision;
     int             year;
     KActionCollection* m_actions;
+    KToggleAction* m_togglePopupsAction;
     KVolumeControl* m_volume;
+    DockWidget* m_dockWidget;
 };
 
 
