@@ -1,5 +1,5 @@
 /*
-   $Id: syna.h,v 1.8 2000/08/11 15:44:48 faure Exp $
+   $Id: syna.h,v 1.9 2003/03/07 22:07:29 waba Exp $
 
    Synaesthesia - program to display sound graphically
    Copyright (C) 1997  Paul Francis Harrison
@@ -16,7 +16,7 @@
 
   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
-  675 Mass Ave, Cambridge, MA 02139, USA.
+  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
   The author may be contacted at:
     phar6@student.monash.edu.au
