@@ -1,7 +1,7 @@
 #ifndef WM_DATABASE_H
 #define WM_DATABASE_H
 /*
- * $Id: wm_database.h,v 1.1 2000/01/18 16:39:50 dfoerste Exp $
+ * $Id: wm_database.h,v 1.1.14.1 2004/11/08 06:56:35 mueller Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -38,7 +38,4 @@ int	save( void );
 void	load( void );
 void	load_settings( void );
 
-extern int wm_db_save_disabled;
-extern int cur_playnew;
-
 #endif /* WM_DATABASE_H */
