@@ -1,5 +1,5 @@
 /*
- * $Id: plat_sun.c,v 1.11 2001/04/10 17:34:52 dfoerste Exp $
+ * $Id: plat_sun.c,v 1.15 2003/05/16 18:30:34 misty Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,7 +25,7 @@
  * Sun-specific drive control routines.
  */
 
-static char plat_sun_id[] = "$Id: plat_sun.c,v 1.11 2001/04/10 17:34:52 dfoerste Exp $";
+static char plat_sun_id[] = "$Id: plat_sun.c,v 1.15 2003/05/16 18:30:34 misty Exp $";
 
 #if defined(sun) || defined(__sun)
 
@@ -76,11 +76,9 @@ static char plat_sun_id[] = "$Id: plat_sun.c,v 1.11 2001/04/10 17:34:52 dfoerste
 int	min_volume = 0;
 int	max_volume = 255;
 
-extern char	*cd_device, *cddaslave_path; 
+static const char *sun_cd_device = NULL; 
 extern int	intermittent_dev;
 
-int	cdda_slave = -1;
-
 int	current_end;
 
 #if defined(SYSV) && defined(SIGTHAW)
@@ -91,7 +89,7 @@ void sigthawinit(void) __attribute__ ((constructor));
 #endif /* GNUC */
 
 static int last_left, last_right;
-static struct wm_drive *thecd;
+static struct wm_drive *thecd = NULL;
 
 /*
  * Handling for Sun's Suspend functionality
@@ -131,7 +129,7 @@ sigthawinit( void )
  * there if there's no CD in the drive.)  This is done so a single SunOS 4.x
  * binary can be used on any 4.x or higher Sun system.
  */
-int
+const char*
 find_cdrom( void )
 {
   if (access("/vol/dev/aliases", X_OK) == 0)
@@ -140,34 +138,35 @@ find_cdrom( void )
       intermittent_dev = 1;
       
       /* If vold is running us, it'll tell us the device name. */
-      cd_device = getenv("VOLUME_DEVICE");
+      sun_cd_device = getenv("VOLUME_DEVICE");
       /*
       ** the path of the device has to include /dev
       ** otherwise we are vulnerable to race conditions
       ** Thomas Biege <thomas@suse.de>
       */
-      if (cd_device == NULL || 
-	  strncmp("/vol/dev/", cd_device, 9) || 
-	  strstr(cd_device, "/../") )
-	cd_device = "/vol/dev/aliases/cdrom0";
+      if (sun_cd_device == NULL || 
+	  strncmp("/vol/dev/", sun_cd_device, 9) || 
+	  strstr(sun_cd_device, "/../") )
+	return "/vol/dev/aliases/cdrom0";
+      else
+        return sun_cd_device;
     }
   else if (access("/dev/rdsk/c0t6d0s2", F_OK) == 0)
     {
       /* Solaris 2.x w/o volume manager. */
-      cd_device = "/dev/rdsk/c0t6d0s2";
+      return "/dev/rdsk/c0t6d0s2";
     }
   else if (access("/dev/rcd0", F_OK) == 0)
     {
-      cd_device = "/dev/rcd0";
+      return "/dev/rcd0";
     }
   else if (access("/dev/rsr0", F_OK) == 0)
-    cd_device = "/dev/rsr0";
+    return "/dev/rsr0";
   else
     {
       fprintf(stderr, "Couldn't find a CD device!\n");
-      return 0;
+      return NULL;
     }
-  return 1;
 } /* find_cdrom() */
 
 /*
@@ -187,22 +186,21 @@ gen_init( struct wm_drive *d )
 int
 wmcd_open( struct wm_drive *d )
 {
-  int		fd;
   static int	warned = 0;
   char	vendor[32] = WM_STR_GENVENDOR;
   char	 model[32] = WM_STR_GENMODEL;
   char	   rev[32] = WM_STR_GENREV;
   
-  if (cd_device == NULL)
-    find_cdrom();
-  
   if (d->fd >= 0)		/* Device already open? */
     {
       wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "wmcd_open(): [device is open (fd=%d)]\n", d->fd);
       return (0);
     }
+  
+  if (d->cd_device == NULL)
+    d->cd_device = find_cdrom();
 
-  d->fd = open(cd_device, 0);
+  d->fd = open(d->cd_device, 0);
   if (d->fd < 0)
     {
       /* Solaris 2.2 volume manager moves links around */
@@ -234,16 +232,19 @@ wmcd_open( struct wm_drive *d )
       return (1);
     }
   
-  /* Now fill in the relevant parts of the wm_drive structure. */
-  fd = d->fd;
-  
   /*
    * See if we can do digital audio.
    */
-#if defined(BUILD_CDDA) && defined(WMCDDA_DONE)
-  if (cdda_init(d))
-    /* WARNING: Old GUI call. How could this survive? */
-    enable_cdda_controls(1);
+#if defined(BUILD_CDDA)
+  if(d->cdda) {
+    if (!gen_cdda_init(d))
+      /* WARNING: Old GUI call. How could this survive? */
+      enable_cdda_controls(1);
+    else {
+      wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "wmcd_open(): failed in gen_cdda_init\n");
+      gen_close(d);
+      return -1;
+    }
 #endif
   
   /* Can we figure out the drive type? */
@@ -260,15 +261,15 @@ wmcd_open( struct wm_drive *d )
 	} else {
 	  fprintf(stderr, "Warning: WorkMan couldn't determine drive type\n");
 	}
-      *d = *(find_drive_struct("Generic", "drive type", ""));
-    } else {
-      *d = *(find_drive_struct(vendor, model, rev));
+      strcpy(vendor, "Generic");
+      strcpy(model, "drive type");
+      strcpy(rev, "");
     }
-  
-  wm_drive_settype(vendor, model, rev);
-  d->fd = fd;
-  
-  (d->init)(d);
+    
+  find_drive_struct(vendor, model, rev);
+    
+  (d->proto->gen_init)(d);
+  thecd = d;
   
   return (0);
 } /* wmcd_open() */
@@ -283,13 +284,7 @@ wmcd_reopen( struct wm_drive *d )
   
   do {
     wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "wmcd_reopen\n");
-    if (d->fd >= 0)		/* Device really open? */
-      {
-	wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "closing the device\n");
-	status = close( d->fd );   /* close it! */
-	/* we know, that the file is closed, do we? */
-	d->fd = -1;
-      }
+    gen_close(d);
     wm_susleep( 1000 );
     wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "calling wmcd_open()\n");
     status = wmcd_open( d ); /* open it as usual */
@@ -334,6 +329,17 @@ wm_scsi( struct wm_drive *d,
 int wm_scsi() { return (-1); }
 #endif
 
+int
+gen_close( struct wm_drive *d )
+{
+  if(d->fd != -1) {
+    wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "closing the device\n");
+    close(d->fd);
+    d->fd = -1;
+  }
+  return 0;
+}
+
 /* Alarm signal handler. */
 static void do_nothing( int x ) { x++; }
 
@@ -344,8 +350,8 @@ static void do_nothing( int x ) { x++; }
  */
 int
 gen_get_drive_status( struct wm_drive *d,
-		      enum wm_cd_modes oldmode,
-		      enum wm_cd_modes *mode,
+		      int oldmode,
+		      int *mode,
 		      int *pos, int *track, int *index )
 {
   struct cdrom_subchnl		sc;
@@ -368,64 +374,11 @@ gen_get_drive_status( struct wm_drive *d,
 	}
     }
   
-#if defined(BUILD_CDDA) && defined(WMCDDA_DONE) /* { */
-  if ((oldmode == WM_CDM_PAUSED || oldmode == WM_CDM_PLAYING 
-       || oldmode == WM_CDM_STOPPED) && cdda_slave > -1)
-    {
-      struct cdda_block	blk;
-      struct pollfd		fds;
-      int			gotone = 0;
-      
-      fds.fd = cdda_slave;
-      fds.events = POLLRDNORM;
-      
-      *mode = oldmode;
-      
-      while (poll(&fds, 1, 0) > 0)
-	{
-	  read(cdda_slave, &blk, sizeof(blk));
-	  gotone = 1;
-	}
-      
-      /* We only want to use the latest status report. */
-      if (gotone)
-	{
-	  if (blk.status == WMCDDA_PLAYED)
-	    {
-	      *track = blk.track;
-	      *index = blk.index;
-	      *pos = blk.minute * 60 * 75 +
-		blk.second * 75 +
-		blk.frame;
-	      
-	      *mode = WM_CDM_PLAYING;
-	    }
-	  else if (blk.status == WMCDDA_DONE)
-	    *mode = WM_CDM_TRACK_DONE;
-	  else if (blk.status == WMCDDA_STOPPED)
-	    {
-	      if (oldmode == WM_CDM_PLAYING || oldmode == WM_CDM_PAUSED)
-		*mode = WM_CDM_PAUSED;
-	      else
-		*mode = WM_CDM_STOPPED;
-	    }
-	  else if (blk.status == WMCDDA_ERROR)
-	    {
-	      /*
-	       * An error near the end of the CD probably
-	       * just means we hit the end.
-	       */
-	      *mode = WM_CDM_TRACK_DONE;
-	    }
-	  else if (blk.status == WMCDDA_EJECTED)
-	    {
-	      *mode = WM_CDM_EJECTED;
-	    }
-	}
-      
-      return (0);
-    }
-#endif /* } */
+#if defined(BUILD_CDDA)
+  if (oldmode == WM_CDM_PAUSED || oldmode == WM_CDM_PLAYING || oldmode == WM_CDM_STOPPED) {
+       CDDARETURN(d) cdda_get_drive_status(d, oldmode, mode, pos, track, index);
+  }
+#endif
   
   /*
    * Solaris 2.2 hangs on this ioctl if someone else ejects the CD.
@@ -588,26 +541,7 @@ gen_play( struct wm_drive *d, int start, int end, int realstart)
   
   current_end = end;
   
-
-  if (cdda_slave > -1)
-    {
-      cmdbuf[0] = 'P';
-      cmdbuf[1] = start / (60 * 75);
-      cmdbuf[2] = (start % (60*75)) / 75;
-      cmdbuf[3] = start % 75;
-      cmdbuf[4] = end / (60*75);
-      cmdbuf[5] = (end % (60*75)) / 75;
-      cmdbuf[6] = end % 75;
-      cmdbuf[7] = realstart / (60 * 75);
-      cmdbuf[8] = (realstart % (60*75)) / 75;
-      cmdbuf[9] = realstart % 75;
-      
-      /* Write the play command and make sure the slave has it. */
-      write(cdda_slave, cmdbuf, 10);
-      get_ack(cdda_slave);
-      
-      return (0);
-    }
+  CDDARETURN(d) cdda_play(d, start, end, realstart);
   
   msf.cdmsf_min0 = start / (60*75);
   msf.cdmsf_sec0 = (start % (60*75)) / 75;
@@ -631,19 +565,7 @@ gen_play( struct wm_drive *d, int start, int end, int realstart)
 int
 gen_pause( struct wm_drive *d )
 {
-  if (cdda_slave > -1)
-    {
-      int	dummy, mode = WM_CDM_PLAYING;
-      
-      write(cdda_slave, "S", 1);
-      get_ack(cdda_slave);
-      /*
-      while (mode != WM_CDM_PAUSED)
-	gen_get_drive_status(d, WM_CDM_PAUSED, &mode, &dummy, &dummy,
-			     &dummy);
-      */
-      return (0);
-    }
+  CDDARETURN(d) cdda_pause(d);
   
   codec_stop();
   return (ioctl(d->fd, CDROMPAUSE));
@@ -655,8 +577,7 @@ gen_pause( struct wm_drive *d )
 int
 gen_resume( struct wm_drive *d )
 {
-  if (cdda_slave > -1)
-    return (1);
+  CDDARETURN(d) cdda_pause(d);
   
   codec_start();
   return (ioctl(d->fd, CDROMRESUME));
@@ -668,18 +589,8 @@ gen_resume( struct wm_drive *d )
 int
 gen_stop( struct wm_drive *d )
 {
-  if (cdda_slave > -1)
-    {
-      write(cdda_slave, "S", 1);
-      get_ack(cdda_slave);
-      
-      /*
-       * The WMCDDA_STOPPED status message will be caught by
-       * gen_get_drive_status.
-       */
-      
-      return (0);
-    }
+  CDDARETURN(d) cdda_stop(d);
+  
   codec_stop();
   return (ioctl(d->fd, CDROMSTOP));
 } /* gen_stop() */
@@ -700,11 +611,9 @@ gen_eject( struct wm_drive *d )
   if (ustat(stbuf.st_rdev, &ust) == 0)
     return (-3);
   
-  if (cdda_slave > -1)
-    {
-      write(cdda_slave, "S", 1);
-      get_ack(cdda_slave);
-    }
+  IFCDDA(d) {
+    cdda_eject(d);
+  }
   
   if (ioctl(d->fd, CDROMEJECT))
     return (-1);
@@ -716,10 +625,10 @@ gen_eject( struct wm_drive *d )
       d->fd = -1;
       /* Also remember to tell the cddaslave since volume
 	 manager switches links around on us */
-      if (cdda_slave > -1)
+      if (d->cdda_slave > -1)
 	{
-	  write(cdda_slave, "E", 1);
-	  get_ack(cdda_slave);
+	  write(d->cdda_slave, "E", 1);
+	  cdda_get_ack(d->cdda_slave);
 	}
     }
   
@@ -765,34 +674,7 @@ gen_set_volume( struct wm_drive *d, int left, int right )
   thecd = d;
 #endif
   
-  if (cdda_slave > -1)
-    {
-      int		bal, vol;
-      unsigned char	cmd[2];
-      
-      bal = (right - left) + 100;
-      bal *= 255;
-      bal /= 200;
-      if (right > left)
-	vol = right;
-      else
-	vol = left;
-      vol *= 255;
-      vol /= 100;
-      
-      cmd[0] = 'B';
-      cmd[1] = bal;
-      write(cdda_slave, cmd, 2);
-      cmd[0] = 'V';
-      cmd[1] = vol;
-      write(cdda_slave, cmd, 2);
-      /*
-       * Don't wait for the ack, or the user won't be able to drag
-       * the volume slider smoothly.
-       */
-      
-      return (0);
-    }
+  CDDARETURN(d) cdda_set_volume(d, left, right);
   
   left = (left * (max_volume - min_volume)) / 100 + min_volume;
   right = (right * (max_volume - min_volume)) / 100 + min_volume;
@@ -804,58 +686,36 @@ gen_set_volume( struct wm_drive *d, int left, int right )
 } /* gen_set_volume() */
 
 /*
- * Read the initial volume from the drive, if available.  Each channel
+ * Read the volume from the drive, if available.  Each channel
  * ranges from 0 to 100, with -1 indicating data not available.
  */
 int
 gen_get_volume( struct wm_drive *d, int *left, int *right )
 {
-#if defined(BUILD_CDDA) && defined(WMCDDA_DONE) /* { */
-  struct cdda_block	blk;
-  
-  if (cdda_slave > -1)
-    {
-      write(cdda_slave, "G", 1);
-      get_ack(cdda_slave);
-      read(cdda_slave, &blk, sizeof(blk));
-      
-      *left = *right = (blk.volume * 100 + 254) / 255;
-      
-      if (blk.balance < 110)
-	*right = (((blk.volume * blk.balance + 127) / 128) *
-		  100 + 254) / 255;
-      else if (blk.balance > 146)
-	*left = (((blk.volume * (255 - blk.balance) +
-		   127) / 128) * 100 + 254) / 255;
-      
-      return (0);
-    }
-#endif /* } */
+  CDDARETURN(d) cdda_get_volume(d, left, right);
   
   *left = *right = -1;
   
   return (wm_scsi2_get_volume(d, left, right));
 } /* gen_get_volume() */
 
-/* Trying to patch things up. Yuck. */
-/* #ifdef BUILD_CDDA */
+#ifdef BUILD_CDDA
 
 /*
- * Try to initialize the CDDA slave.  Returns 0 on error.
+ * Try to initialize the CDDA slave.  Returns 0 on success.
  */
 int
-cdda_init( struct wm_drive *d )
+gen_cdda_init( struct wm_drive *d )
 {
-#if defined(BUILD_CDDA) && defined(WMCDDA_DONE) /* { */
   int	slavefds[2];
   
-  if (cdda_slave > -1)
-    return (1);
+  if (d->cdda_slave > -1)
+    return (0);
   
   if (socketpair(AF_UNIX, SOCK_STREAM, 0, slavefds))
     {
       perror("socketpair");
-      return (0);
+      return (-1);
     }
   
   switch (fork()) 
@@ -867,9 +727,9 @@ cdda_init( struct wm_drive *d )
       close(slavefds[1]);
       close(d->fd);
       /* Try the default path first. */
-      execl(cddaslave_path, cddaslave_path, cd_device, NULL);
+      execl(cddaslave_path, cddaslave_path, d->cd_device, (void *)0);
       /* Search $PATH if that didn't work. */
-      execlp("cddaslave", "cddaslave", cd_device, NULL);
+      execlp("cddaslave", "cddaslave", d->cd_device, (void *)0);
       perror(cddaslave_path);
       exit(1);
       
@@ -877,135 +737,23 @@ cdda_init( struct wm_drive *d )
       close(slavefds[0]);
       close(slavefds[1]);
       perror("fork");
-      return (0);
+      return (-2);
     }
   
   close(slavefds[1]);
-  cdda_slave = slavefds[0];
+  d->cdda_slave = slavefds[0];
   
-  if (!get_ack(cdda_slave))
+  if (!cdda_get_ack(d->cdda_slave))
     {
-      cdda_slave = -1;
+      d->cdda_slave = -1;
       codec_start();
-      return (0);
+      return (-3);
     }
   
-  return (1);
-  
-#else /* BUILD_CDDA only (WMCDDA_DONE } { */
-  /*
-   * If we're not building CDDA support, don't even bother trying.
-   */
   return (0);
-#endif
-} /* cdda_init() */
-
-/*
- * Wait for an acknowledgement from the CDDA slave.
- */
-static int
-get_ack(int fd)
-{
-#if defined(WMCDDA_DONE) /* { */
-  struct cdda_block	blk;
+}
   
-  do
-    if (read(fd, &blk, sizeof(blk)) <= 0)
-      return (0);
-  while (blk.status != WMCDDA_ACK);
-#endif /* } */
-  return (1);
-} /* get_ack() */
-
-/*
- * Turn off the CDDA slave.
- */
-void
-cdda_kill( struct wm_drive *d )
-{
-  if (cdda_slave > -1)
-    {
-      write(cdda_slave, "Q", 1);
-      get_ack(cdda_slave);
-      wait(NULL);
-      cdda_slave = -1;
-      codec_start();
-    }
-} /* cdda_kill() */
-
-/*
- * Tell the CDDA slave to set the play direction.
- */
-void
-gen_set_direction( int newdir )
-{
-  unsigned char	buf[2];
-  
-  if (cdda_slave > -1)
-    {
-      buf[0] = 'd';
-      buf[1] = newdir;
-      write(cdda_slave, buf, 2);
-      get_ack(cdda_slave);
-    }
-} /* gen_set_direction() */
-
-/*
- * Tell the CDDA slave to set the play speed.
- */
-void
-gen_set_speed( int speed )
-{
-  unsigned char	buf[2];
-  
-  if (cdda_slave > -1)
-    {
-      buf[0] = 's';
-      buf[1] = speed;
-      write(cdda_slave, buf, 2);
-      get_ack(cdda_slave);
-    }
-} /* gen_set_speed() */
-
-/*
- * Tell the CDDA slave to set the loudness level.
- */
-void
-gen_set_loudness( int loud )
-{
-  unsigned char	buf[2];
-  
-  if (cdda_slave > -1)
-    {
-      buf[0] = 'L';
-      buf[1] = loud;
-      write(cdda_slave, buf, 2);
-      get_ack(cdda_slave);
-    }
-} /* gen_set_loudness() */
-
-/*
- * Tell the CDDA slave to start (or stop) saving to a file.
- */
-void
-gen_save( char *filename )
-{
-  int	len;
-  
-  if (filename == NULL || filename[0] == '\0')
-    len = 0;
-  else
-    len = strlen(filename);
-  write(cdda_slave, "F", 1);
-  write(cdda_slave, &len, sizeof(len));
-  if (len)
-    write(cdda_slave, filename, len);
-  get_ack(cdda_slave);
-} /* gen_save() */
-
-/*
-#endif
-*/
+#endif /* BUILD_CDDA */
 
 /*
  * The following code activates the internal CD audio passthrough on
@@ -1125,7 +873,7 @@ codec_init( void )
   foo.record.port = port;
   foo.record.balance = foo.play.balance = AUDIO_MID_BALANCE;
 #ifdef BUILD_CDDA
-  if (cdda_slave > -1)
+  if (d->cdda_slave > -1)
     foo.monitor_gain = 0;
   else
 #endif
@@ -1221,4 +969,4 @@ gen_get_cdtext(struct wm_drive *d, unsigned char **pp_buffer, int *p_buffer_leng
   return wm_scsi_get_cdtext(d, pp_buffer, p_buffer_lenght);
 } /* gen_get_cdtext() */
 
-#endif /* sun } */
+#endif /* sun */
