@@ -8,7 +8,7 @@
  *
  *  For more information look at the file COPYRIGHT in this package
  *
- * $Id: cdromAccess.cpp,v 1.6 2003/10/05 16:53:05 adrian Exp $
+ * $Id: cdromAccess.cpp,v 1.9 2004/05/11 16:32:08 cartman Exp $
  *
  */
 
@@ -24,15 +24,12 @@
 
 #ifdef OS_Linux
   #include <linux/version.h>
-#if 0
-/* this breaks the build on ia64 and s390 for example.
-   sys/types.h is already included and should provide __u64.
-   please tell where we really need this and let's try to find
-   a working #if case for everyone ... adrian@suse.de */
-  #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,5,50)
-  typedef unsigned long long  __u64;
+  #include <sys/types.h>
+  #ifndef __u64
+  #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,5,70)
+  typedef unsigned long long __u64;
+  #endif
   #endif
-#endif
   #include "cdromAccess_Linux.cpp"
 #endif
 
