@@ -13,10 +13,6 @@
 
 #include "cdromToc.h"
 #include "cdromRawAccess.h"
-#ifndef __GNUC__
-#define __GNUC__ 1
-#endif
-#undef __STRICT_ANSI__
 #include <asm/types.h>
 #include <linux/cdrom.h>
 #include <sys/ioctl.h>
