@@ -22,6 +22,10 @@
 #define NDEBUG
 #include <assert.h>
 
+
+#define DEBUG_DECODERCLASS(x)
+//#define DEBUG_DECODERCLASS(x) x
+
 /* Array mapping zigzag to array pointer offset. */
 
 
@@ -94,7 +98,7 @@ DecoderClass::DecoderClass(VideoDecoder* vid_stream,
   lmmx=mm_support();
 #else
   lmmx=false;
-  cout << "no INTEL arch- disable MMX in decoderClass"<<endl;
+  DEBUG_DECODERCLASS(cout << "no INTEL arch- disable MMX in decoderClass"<<endl;)
 
 #endif
 
@@ -185,12 +189,12 @@ int DecoderClass::decodeMBAddrInc() {
   val = mb_addr_inc[index].value;
   mpegVideoStream->flushBits(mb_addr_inc[index].num_bits);
   if (mb_addr_inc[index].num_bits==0) {
-    printf("num_bits==0\n");
+    DEBUG_DECODERCLASS(cout<<"num_bits==0"<<endl;)
     val=1;
   }
 
   if (val == -1) {
-    cout <<"EROR: decodeMBAddrInc"<<endl;
+    DEBUG_DECODERCLASS(cout <<"EROR: decodeMBAddrInc"<<endl;)
     val=MB_STUFFING;
   }
   return val;
@@ -298,7 +302,7 @@ void DecoderClass::decodeMBTypeB(int& quant,int& motion_fwd,
   pat = mb_type_B[index].mb_pattern;					
   intra = mb_type_B[index].mb_intra;					
   if (index == 0) {
-    cout << "error in decodeMBTypeB"<<endl;
+    DEBUG_DECODERCLASS(cout << "error in decodeMBTypeB"<<endl;)
   }
   mpegVideoStream->flushBits(mb_type_B[index].num_bits);	
 }
@@ -339,7 +343,7 @@ void DecoderClass::decodeMBTypeI(int& quant,int& motion_fwd,
   intra = 1;								
   quant = quantTbl[index];						
   if (quant == MPGDECODE_ERROR) {
-    cout << "decodeMBTypeI Error"<<endl;
+    DEBUG_DECODERCLASS(cout << "decodeMBTypeI Error"<<endl;)
   }
   if (index) {								
     mpegVideoStream->flushBits (1 + quant);
@@ -384,7 +388,7 @@ void DecoderClass::decodeMBTypeP(int& quant,int& motion_fwd,
   pat = mb_type_P[index].mb_pattern;					
   intra = mb_type_P[index].mb_intra;					
   if (index == 0) {
-    cout << "error in decodeMBTypeP"<<endl;
+    DEBUG_DECODERCLASS(cout << "error in decodeMBTypeP"<<endl;)
   }
   mpegVideoStream->flushBits(mb_type_P[index].num_bits);	
 }
@@ -604,7 +608,7 @@ void DecoderClass::ParseReconBlock(int& n,int& mb_intra,
 
   int coeffCount=0;
   if (mpegVideoStream->hasBytes(512) == false) {
-    cout << "cannot get 512 raw bytes"<<endl;
+    DEBUG_DECODERCLASS(cout << "cannot get 512 raw bytes"<<endl;)
     return;
   }
 
