@@ -54,7 +54,8 @@ X11Surface::X11Surface() {
 
 
   xWindow->display=XOpenDisplay(NULL);
-  XFlush(xWindow->display);
+  if (xWindow->display)
+     XFlush(xWindow->display);
   xWindow->redMask=0;
   xWindow->greenMask=0;
   xWindow->blueMask=0;
@@ -71,8 +72,9 @@ X11Surface::X11Surface() {
 
 X11Surface::~X11Surface() {
   close();
-  XCloseDisplay(xWindow->display);
-  delete xWindow;
+  if (xWindow->display)
+     XCloseDisplay(xWindow->display);
+  free(xWindow);
 
   for (int count=0 ; count<images ; count++) {
 	  if (imageList[count] != NULL)
