@@ -15,27 +15,6 @@ class KLineEdit;
 
 namespace Arts {class TraderOffer;}
 
-class Types : public CModule
-{
-Q_OBJECT
-public:
-	Types(QObject *parent=0);
-	virtual ~Types();
-	virtual void save();
-	virtual void reopen();
-
-	static QString commaVector(Arts::TraderOffer *t, const char *field, bool limit=false);
-
-public slots:
-	void selectionChanged(QListViewItem *item);
-
-private:
-	KListView *list;
-	bool first;
-	QTextView *text;
-	MimeTypeTree *mimes;
-};
-
 class QCheckBox;
 class KURLRequester;
 
