@@ -171,10 +171,8 @@ void Downloader::getNext()
 {
 	if (current) return;
 	if (!mStarted) return;
-
+	if (mQueue.isEmpty()) return;
 	current=mQueue.take(0);
-	if (!current)
-		return;
 
 	// open the QFile
 	localfile=new QFile(current->local);
@@ -182,7 +180,7 @@ void Downloader::getNext()
 
 	mJob= KIO::get(current->file, true, false);
 	connect(mJob, SIGNAL(data(KIO::Job*, const QByteArray&)), SLOT(data(KIO::Job*, const QByteArray&)));
-
+	connect(mJob, SIGNAL(result(KIO::Job*)), SLOT(jobDone(KIO::Job*)));
 	connect(mJob, SIGNAL(percent(KIO::Job*, unsigned long)), SLOT(percent(KIO::Job*, unsigned long)));
 
 	if (mTimeout)
@@ -192,15 +190,8 @@ void Downloader::getNext()
 	connect(mTimeout, SIGNAL(timeout()), SLOT(giveUpWithThisDownloadServerIsRunningNT()));
 }
 
-void Downloader::data(KIO::Job *j, const QByteArray &data)
+void Downloader::data(KIO::Job *, const QByteArray &data)
 {
-	if (!data.size())
-	{ // file is done downloading
-		jobDone(j);
-		delete mTimeout;
-		mTimeout=0;
-		return;
-	}
 	localfile->writeBlock(data);
 	localfile->flush();
 	delete mTimeout;
@@ -209,6 +200,8 @@ void Downloader::data(KIO::Job *j, const QByteArray &data)
 
 void Downloader::jobDone(KIO::Job *)
 {
+	delete mTimeout;
+	mTimeout=0;
 	current->notifier->downloadFinished();
 	if (mStarted)
 		emit dequeued(current->notifier);
