@@ -1,4 +1,4 @@
-// $Id: engine.cpp,v 1.89.2.3 2003/06/27 07:12:52 staikos Exp $
+// $Id: engine.cpp,v 1.96 2004/03/02 00:19:22 jriddell Exp $
 
 #include <noatun/engine.h>
 #include <noatun/equalizer.h>
@@ -31,6 +31,8 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <math.h>
+
 
 static Arts::PlayObject nullPO() { return Arts::PlayObject::null(); }
 
@@ -87,15 +89,15 @@ namespace VolumeControls
 			}
 
 		}
-		
+
 		virtual ~Hardware() { ::close(fd); }
-		
+
 		virtual void setVolume(int percent)
 		{
 			percent=percent+(percent<<8);
 			ioctl(fd, MIXER_WRITE(4), &percent);
 		}
-		
+
 		virtual int volume() const
 		{
 			int volume, left, right;
@@ -130,15 +132,17 @@ namespace VolumeControls
 		virtual void setVolume(int percent)
 		{
 			mVolume=percent;
+			float vol = pow(2.0, ((400 - (100-percent)*12)/200.0))/4.0;
+			if (percent == 0) vol = 0.0;
 			if (!volumeControl.isNull())
-				volumeControl.percent((float)percent/100.0);
+				volumeControl.percent(vol);
 		}
-		
+
 		virtual int volume() const
 		{
 			return mVolume;
 		}
-		
+
 	private:
 		Noatun::StereoVolumeControlSSE volumeControl;
 		long id;
@@ -161,12 +165,12 @@ namespace VolumeControls
 			if (!volumeControl.isNull())
 				volumeControl.percent((float)percent/100.0);
 		}
-		
+
 		virtual int volume() const
 		{
 			return mVolume;
 		}
-		
+
 	private:
 		Noatun::StereoVolumeControl volumeControl;
 		long id;
@@ -181,7 +185,7 @@ namespace VolumeControls
 		else
 		{
 #endif
-			if (Arts::CpuInfo::flags()&Arts::CpuInfo::CpuSSE)
+			if (!getenv("NO_SSE") && Arts::CpuInfo::flags()&Arts::CpuInfo::CpuSSE)
 				return new SoftwareSSE(e);
 			else
 				return new Software(e);
@@ -205,12 +209,12 @@ public:
 		  volumeControl(0), session(Noatun::Session::null())
 		{
 		}
-	
+
 	~EnginePrivate()
 	{
 		visStack=Noatun::StereoEffectStack::null();
 	}
-	
+
 	KDE::PlayObject *playobj;
 	Arts::SoundServerV2 server;
 	Arts::Synth_AMAN_PLAY amanPlay;
@@ -247,7 +251,7 @@ Engine::Engine(QObject *parent) : QObject(parent, "Engine"), mPlay(false)
 	// Connect to aRts
 	if (!initArts())
 	{
-		KMessageBox::error(0, i18n("There was an error communicating to the aRts daemon."), i18n("Danger, Will Robinson!"));
+		KMessageBox::error(0, i18n("There was an error communicating to the aRts daemon."), i18n("aRts error"));
 		exit(0);
 	}
 
@@ -275,7 +279,7 @@ bool Engine::open(const PlaylistItem &file)
 {
 	if(!initArts()) return false;
 	d->playobj=0;
-	
+
 	string objectType=(const char*)file.playObject();
 	if (!objectType.length())
 	{
@@ -284,7 +288,7 @@ bool Engine::open(const PlaylistItem &file)
 	}
 
 	KDE::PlayObjectFactory factory(d->server);
-	
+
 	factory.setAllowStreaming(file.isProperty("stream_"));
 
 	if (file.isProperty("stream_"))
@@ -299,7 +303,7 @@ bool Engine::open(const PlaylistItem &file)
 		u.setPath(file.file());
 		d->playobj=factory.createPlayObject(u, file.mimetype(), false);
 	}
-	
+
 	if (!d->playobj || d->playobj->isNull())
 	{
 		delete d->playobj;
@@ -374,7 +378,7 @@ void Engine::seek(int msec) // pass time in msecs
 int Engine::position()
 {
 	if(!d->playobj) return -1;
-	
+
 	Arts::poTime time(d->playobj->currentTime());
 	return (int)(time.ms + (time.seconds*1000)); // return position in milliseconds
 }
@@ -422,7 +426,7 @@ bool Engine::initArts()
 	if ( d->server.isNull() || d->server.error()  )
 	{
 		d->server = Arts::Reference("global:Arts_SoundServerV2");
-		int volume = d->volumeControl ? d->volumeControl->volume() : 100;
+		int volume = d->volumeControl ? d->volumeControl->volume() : -1;
 		delete d->volumeControl;
 		d->volumeControl=0;
 
@@ -446,7 +450,7 @@ bool Engine::initArts()
 					X11CommConfig.writeEntry("GlobalComm", "Arts::X11GlobalComm");
 				else
 					X11CommConfig.writeEntry("GlobalComm", "Arts::TmpGlobalComm");
-	
+
 				X11CommConfig.sync();
 			}
 
@@ -488,7 +492,7 @@ bool Engine::initArts()
 			d->amanPlay = Arts::DynamicCast(
 					d->server.createObject("Arts::Synth_AMAN_PLAY")
 				);
-			
+
 			if (d->amanPlay.isNull())
 				goto crapOut;
 
@@ -502,10 +506,10 @@ bool Engine::initArts()
 				            << "compiling kdemultimedia in a --prefix different "
 				            << "from arts.  It may also be from two conflicting "
 					    << "packages, so uninstall every arts/artsd package "
-					    << "you have installed and try againe." << endl;
-				
+					    << "you have installed and try again." << endl;
+
 			}
-			
+
 			d->amanPlay.title("noatun");
 			d->amanPlay.autoRestoreID("noatun");
 			d->amanPlay.start();
@@ -534,10 +538,11 @@ bool Engine::initArts()
 			d->visStack=Arts::DynamicCast(
 				d->server.createObject("Noatun::StereoEffectStack"));
 			d->visStack.start();
-			
+
 			d->globalEffectStack.insertBottom(d->visStack, "Visualization Stack");
 			d->volumeControl=VolumeControls::volumeControl(this);
-			d->volumeControl->setVolume(volume);
+			if (volume != -1)
+				d->volumeControl->setVolume(volume);
 		}
 		else
 		{
