@@ -66,7 +66,10 @@ void Player::handleButtons()
 void Player::back()
 {
 	if (napp->playlist()->previous())
+	{
+		stop();
 		play();
+	}
 }
 
 void Player::stop()
@@ -75,6 +78,7 @@ void Player::stop()
 	position=0;
 	mEngine->stop();
 	emit stopped();
+	mCurrent=0;
 }
 
 void Player::play()
@@ -215,8 +219,8 @@ void Player::posTimeout()
 
 QString Player::lengthString(int _position)
 {
-  if (!current())
-    return QString("--:--/--:--");
+	if (!current())
+		return QString("--:--/--:--");
 
 	QString posString;
 	QString lenString;
@@ -231,12 +235,24 @@ QString Player::lengthString(int _position)
 	}
 	else
 	{ // get the position
+		bool remain = napp->displayRemaining() && current();
+		if (remain && current().length()<0)
+		{
+			remain = false;
+		}
+
+		if (remain)
+		{
+			_position = current().length() - _position;
+		}
+		
 		secs = _position / 1000; // convert milliseconds -> seconds
 		seconds = secs % 60;
 		minutes = (secs - seconds) / 60;
 
 		// the string has to look like '00:00/00:00'
 		posString.sprintf("%.2d:%.2d/", minutes, seconds);
+		if (remain) posString.prepend('-');
 	}
 
 	if (!current() || current().length()<0)
