@@ -44,7 +44,7 @@ QCString PlaylistItemData::playObject() const
 
 	std::vector<Arts::TraderOffer> *offers = query.query();
 	if (!offers) return "";
-	
+
 	if(!offers->empty())
 		objectType = offers->front().interfaceName();
 
@@ -57,13 +57,13 @@ QString PlaylistItemData::title() const
 {
 	if (isProperty("realtitle"))
 		return property("realtitle");
-	
+
 
 	// "$(property)"
 	QString format=napp->titleFormat();
 
 	QRegExp find("(?:(?:\\\\\\\\))*\\$\\((.*)");
-	
+
 	int start=0;
 	while (start != -1)
 	{
@@ -74,7 +74,7 @@ QString PlaylistItemData::title() const
 		if (start>0 && format[start-1]=='\\')
 		{
 			// yes, so half the amount of backslashes
-			
+
 			// count how many there are first
 			QRegExp counter("([\\\\]+)");
 			counter.search(format, start-1);
@@ -117,7 +117,7 @@ QString PlaylistItemData::title() const
 			i++;
 		}
 
-		
+
 		for (; i < cont.length(); ++i)
 		{
 			if (cont[i]!='"' && cont[i]!=')')
@@ -139,18 +139,24 @@ QString PlaylistItemData::title() const
 			i++;
 		}
 		i++;
-		
-		
+
+
 		QString propval = property(propname);
 		if (propname == "title" && !propval.length())
 		{
 			propval = url().filename();
 		}
-		
+		else if (propname == "comment")
+		{
+			// comments can contain newlines
+			// these are not wanted in a formatted title
+			propval.replace('\n', ' ');
+		}
+
 		if (propval.length())
 		{
 			propval = prefix+propval+suffix;
-			format.replace(start, i+2, propval);	
+			format.replace(start, i+2, propval);
 			start += propval.length();
 		}
 		else
@@ -159,7 +165,7 @@ QString PlaylistItemData::title() const
 		}
 	}
 	return format;
-	
+
 }
 
 int PlaylistItemData::length() const
@@ -191,33 +197,37 @@ PlaylistItem::~PlaylistItem()
 
 PlaylistItem &PlaylistItem::operator =(const PlaylistItem &source)
 {
+	if (source)
+		source.addRef();
 	removeRef();
 	mData=source.mData;
-	addRef();
 	return *this;
 }
 
 PlaylistItem &PlaylistItem::operator =(PlaylistItemData *source)
 {
+	if (source)
+		source->addRef();
 	removeRef();
 	mData=source;
-	addRef();
 	return *this;
 }
 
 const PlaylistItem &PlaylistItem::operator =(const PlaylistItem &source) const
 {
+	if (source)
+		source.addRef();
 	removeRef();
 	mData=source.mData;
-	addRef();
 	return *this;
 }
 
 const PlaylistItem &PlaylistItem::operator =(const PlaylistItemData *source) const
 {
+	if (source)
+		const_cast<PlaylistItemData*>(source)->addRef();
 	removeRef();
 	mData=const_cast<PlaylistItemData*>(source);
-	addRef();
 	return *this;
 }
 
@@ -256,7 +266,7 @@ bool PlaylistItemData::operator != (const PlaylistItemData &d) const
 {
 	return ! (*this==d);
 }
-	
+
 
 
 
@@ -278,7 +288,7 @@ Playlist::Playlist(QObject *parent, const char *name) : QObject(parent, name)
 
 Playlist::~Playlist()
 {
-	
+
 }
 
 void Playlist::toggleList()
@@ -298,7 +308,7 @@ int Playlist::handleArguments()
 	for (i=0; i < args->count(); i++)
 	{
 		KURL u(args->url(i));
-		if (!u.isMalformed())
+		if (u.isValid())
 			addFile(u, play);
 		play=false;
 	}
@@ -321,7 +331,7 @@ QValueList<PlaylistItem> Playlist::select(
 		{
 			k=*key;
 			v=i.property(k);
-			
+
 			for (val = values.begin(); val != values.end() && limit; ++val)
 			{
 				if ((*val).length()==0 && v.length()==0)
@@ -334,10 +344,10 @@ QValueList<PlaylistItem> Playlist::select(
 				{
 					if (
 							(!caseSensitive && (*val).lower()==v.lower())
-							|| 
+							||
 							(caseSensitive && (*val)==v)
 						)
-							
+
 					{
 						list.append(i);
 						limit--;
@@ -360,7 +370,7 @@ QValueList<PlaylistItem> Playlist::select(
 	}
 	return list;
 }
-	
+
 QValueList<PlaylistItem> Playlist::select(
 		const QString &key, const QString &value,
 		int limit, bool exact, bool caseSensitive
