@@ -62,7 +62,7 @@
 #include <qvbox.h>
 
 Excellent::Excellent()
-	: KMainWindow()
+	: KMainWindow(0, "NoatunExcellent")
 	, UserInterface()
 {
 	setAcceptDrops(true);
@@ -83,10 +83,11 @@ Excellent::Excellent()
 	NoatunStdAction::playlist(actionCollection(), "show_playlist");
 
 	volumeAction = new KToggleAction(i18n("Show &Volume Control"), 0, this, SLOT(showVolumeControl()), actionCollection(), "show_volumecontrol");
+	volumeAction->setCheckedState(i18n("Hide &Volume Control"));
 	NoatunStdAction::effects(actionCollection(), "effects");
 	NoatunStdAction::equalizer(actionCollection(), "equalizer");
 
-	loop = NoatunStdAction::loop(actionCollection(), "loop_style");
+	NoatunStdAction::loop(actionCollection(), "loop_style");
 
 	createGUI("excellentui.rc");
 
@@ -137,7 +138,7 @@ Excellent::Excellent()
 	napp->player()->handleButtons();
 
 	connect(napp->player(), SIGNAL(timeout()), this, SLOT(slotTimeout()));
-	connect(napp->player(), SIGNAL(loopTypeChange(int)), this, SLOT(changeLoopType(int)));
+	connect(napp->player(), SIGNAL(loopTypeChange(int)), this, SLOT(slotLoopTypeChanged(int)));
 
 	/* This skipToWrapper is needed to pass milliseconds to Player() as everybody
 	 * below the GUI is based on milliseconds instead of some unprecise thingy
@@ -149,7 +150,7 @@ Excellent::Excellent()
 
 	setCaption("Noatun");
 	setIcon(SmallIcon("noatun"));
-	changeLoopType(Player::None);
+	//slotLoopTypeChanged(Player::None);
 	changeStatusbar();
 	handleLengthString("--:--/--:--");
 
@@ -306,10 +307,10 @@ void Excellent::skipToWrapper(int second) // wrap int to int _and_ seconds to ms
 	emit skipTo((int)(second*1000));
 }
 
-void Excellent::changeLoopType(int t)
+void Excellent::slotLoopTypeChanged(int type)
 {
 	static const int time = 2000;
-	switch (t)
+	switch (type)
 	{
 	case Player::None:
 		statusBar()->message(i18n("No looping"), time);
