@@ -266,7 +266,7 @@ int KJPrefs::visType ( void ) const
 	else if ( mGuiSettingsWidget->visAnalyzer->isChecked() ) // FFT Analyzer
 		return KJVisScope::FFT;
 	else
-		return KJVisScope::Null; // emergency exit :)
+		return KJVisScope::StereoFFT; //Null; // emergency exit :)
 }
 
 void KJPrefs::setVisType ( int vis )
@@ -285,6 +285,12 @@ void KJPrefs::setVisType ( int vis )
 			mGuiSettingsWidget->visAnalyzer->setChecked(true);
 			break;
 
+		case KJVisScope::StereoFFT:
+			mGuiSettingsWidget->visNone->setChecked(false);
+			mGuiSettingsWidget->visScope->setChecked(false);
+			mGuiSettingsWidget->visAnalyzer->setChecked(false);
+			break;
+
 		case KJVisScope::Mono:
 			mGuiSettingsWidget->visNone->setChecked(false);
 			mGuiSettingsWidget->visScope->setChecked(true);
@@ -369,7 +375,7 @@ void KJPrefs::installNewSkin( void )
 
 	KURL srcFile ( mSkinselectorWidget->mSkinRequester->url() );
 
-	kdDebug(66666) << "file to work on: " << srcFile.path().latin1() << endl;
+	//kdDebug(66666) << "file to work on: " << srcFile.path().latin1() << endl;
 
 	if ( !srcFile.isValid() || srcFile.isEmpty() ) // stop working on broken URLs
 	{
@@ -379,7 +385,7 @@ void KJPrefs::installNewSkin( void )
 
 	if ( !srcFile.isLocalFile() )  // TODO: Download file into tmp dir + unpack afterwards
 	{
-		KMessageBox::sorry ( this, i18n("Non-Local files aren't supported yet") );
+		KMessageBox::sorry ( this, i18n("Non-Local files are not supported yet") );
 		return;
 	}
 
