@@ -16,22 +16,24 @@
 
 VISQueue::VISQueue(int elements) {
   this->elements=elements;
-  int i;
-  for(i=0;i<elements;i++) {
+  
+  visArrayQueue = new std::vector<float>*[elements];
+  for(int i=0;i<elements;i++)
+  {
     visArrayQueue[i]=new std::vector<float>;
   }
 
 }
 
 VISQueue::~VISQueue() {
-  int i;
-
-  for(i=0;i<elements;i++) {
+  for(int i=0;i<elements;i++) {
     delete visArrayQueue[i];
   }
+  delete [] visArrayQueue;
 }
 
-std::vector<float>* VISQueue::getElement(int i) {
+std::vector<float>* VISQueue::getElement(int i)
+{
   if ( (i < 0) || (i>elements) ) {
     return visArrayQueue[0];
   }
